ClinVar This!
=============

ClinVar This! is a Python-based software for the easy submission of variants to ClinVar.

.. toctree::
    :maxdepth: 1
    :caption: Contents

    installation
    usage_library
    usage_cli

.. toctree::
    :maxdepth: 1
    :caption: Project Info

    contributing
    authors
    history

.. toctree::
    :maxdepth: 1
    :caption: CLI

    cli

.. toctree::
    :maxdepth: 1
    :caption: API

    clinvar_api/modules
    clinvar_api/clinvar_api
    clinvar_api/clinvar_api.msg
    clinvar_api/clinvar_api.models

    clinvar_this/modules
    clinvar_this/clinvar_this

Indices and tables
==================
* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
